==> flatland-model-diagram-editor-0.5.2.tar.gz: flatland-model-diagram-editor-0.5.2/flatland/database/population/connector/name_spec_instances.py <==
"""
name_spec_instances.py
"""

population = [
    # connector location names
    {'connector location': 'binary association', 'Diagram type': 'class', 'Notation': 'Starr',
     'Vertical axis buffer': 6, 'Horizontal axis buffer': 6, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},
    {'connector location': 'generalization', 'Diagram type': 'class', 'Notation': 'Starr',
     'Vertical axis buffer': 13, 'Horizontal axis buffer': 16, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},

    {'connector location': 'binary association', 'Diagram type': 'class', 'Notation': 'xuml',
     'Vertical axis buffer': 11, 'Horizontal axis buffer': 11, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},
    {'connector location': 'generalization', 'Diagram type': 'class', 'Notation': 'xuml',
     'Vertical axis buffer': 11, 'Horizontal axis buffer': 11, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},

    {'connector location': 'binary association', 'Diagram type': 'class', 'Notation': 'Shlaer-Mellor',
     'Vertical axis buffer': 11, 'Horizontal axis buffer': 11, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},
    {'connector location': 'generalization', 'Diagram type': 'class', 'Notation': 'Shlaer-Mellor',
     'Vertical axis buffer': 11, 'Horizontal axis buffer': 11, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},

    # connector location names
    {'connector location': 'class mult', 'Diagram type': 'class', 'Notation': 'Starr',
     'Vertical axis buffer': 8, 'Horizontal axis buffer': 8, 'Vertical end buffer': 10, 'Horizontal end buffer': 10,
     'Default name': 'xx', 'Optional': False},
]

==> flatland-model-diagram-editor-0.16.1.tar.gz: flatland-model-diagram-editor-0.16.1/flatland/database/population/connector/name_spec_instances.py <==
"""
name_spec_instances.py
"""

population = [
    # Connector location names
    {'Connector location': 'binary association', 'Diagram type': 'class', 'Notation': 'Starr',
     'Vertical axis buffer': 6, 'Horizontal axis buffer': 6, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},
    {'Connector location': 'generalization', 'Diagram type': 'class', 'Notation': 'Starr',
     'Vertical axis buffer': 13, 'Horizontal axis buffer': 16, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},

    {'Connector location': 'binary association', 'Diagram type': 'class', 'Notation': 'xUML',
     'Vertical axis buffer': 11, 'Horizontal axis buffer': 11, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},
    {'Connector location': 'generalization', 'Diagram type': 'class', 'Notation': 'xUML',
     'Vertical axis buffer': 11, 'Horizontal axis buffer': 11, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},

    {'Connector location': 'binary association', 'Diagram type': 'class', 'Notation': 'Shlaer-Mellor',
     'Vertical axis buffer': 11, 'Horizontal axis buffer': 11, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},
    {'Connector location': 'generalization', 'Diagram type': 'class', 'Notation': 'Shlaer-Mellor',
     'Vertical axis buffer': 11, 'Horizontal axis buffer': 11, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},

    # Connector location names
    {'Connector location': 'class mult', 'Diagram type': 'class', 'Notation': 'Starr',
     'Vertical axis buffer': 8, 'Horizontal axis buffer': 8, 'Vertical end buffer': 10, 'Horizontal end buffer': 10,
     'Default name': 'xx', 'Optional': False},
]
